Documentation
¶
Overview ¶
Package identifybin is a package for identifying the operating system, architecture, and endianess of a binary.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BinaryType ¶
BinaryType is the type of binary
func DetectOSAndArch ¶
func DetectOSAndArch(input interface{}) (BinaryType, error)
DetectOSAndArch downloads the first n bytes of a file
Click to show internal directories.
Click to hide internal directories.